@@ -3,6 +3,7 @@
 import json
 
 from ..common.base import Base
+from ..common.config import *
 
 
 class ReportApi(Base):
@@ -10,6 +11,11 @@ class ReportApi(Base):
         api_url = self.__get_api_url()
         return self.api_post(api_url, data=json.dumps(report))
 
+    def set_report_api(self, report):
+        api_action_name = 'set'
+        api_url = self.__get_api_url(api_action_name)
+        return self.api_post(api_url, data=json.dumps(report))
+
     def delete_report_api(self, report_id):
         api_url = self.__get_api_url(report_id)
         return self.api_delete(api_url)
@@ -22,14 +28,22 @@ class ReportApi(Base):
         api_url = self.__get_api_url(parameter_id)
         return self.api_get(api_url, params={})
 
-    def get_all_reports_by_name_api(self, name):
-        api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'name': name})
-
-    def get_all_reports_by_name_and_file_path_api(self, name, file_path):
+    def get_all_reports_by_name_api(self, name,
+                                    page=DEF_PAGE,
+                                    page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
         return self.api_get(api_url, params={'name': name,
-                                             'file_path': file_path})
+                                             'page': page,
+                                             'page_size': page_size})
+
+    def get_all_reports_by_name_and_file_path_api(self, name, file_path,
+                                                  page=DEF_PAGE,
+                                                  page_size=DEF_PAGE_SIZE):
+        api_url = self.__get_api_url()
+        return self.api_get(api_url, params={'name': name,
+                                             'file_path': file_path,
+                                             'page': page,
+                                             'page_size': page_size})
 
     #
     # Private Methods
