@@ -336,7 +336,7 @@ class CalibrationClient(CalibrationApi,
         report = Report(self, rep_name, rep_path,
                         rep_flg_available, rep_description)
 
-        resp = report.create()
+        resp = report.set()
 
         if resp['success']:
             report = resp['data']
@@ -604,12 +604,12 @@ class CalibrationClient(CalibrationApi,
 
         # Get calibration_constant_version
         if ret_strategy == 'pdu_prior_in_time':
-            resp = CalibrationConstantVersion.get_by_uk(self,
-                                                        # Latest added CC!
-                                                        cc_ids[0],
-                                                        phy_det_unit_id,
-                                                        event_at,
-                                                        snapshot_at)
+            # resp = CalibrationConstantVersion.get_by_uk(self,
+            resp = CalibrationConstantVersion.get_prior_in_time(self,
+                                                                cc_ids,
+                                                                phy_det_unit_id,
+                                                                event_at,
+                                                                snapshot_at)
 
         elif ret_strategy == 'detector_closest_by_time':
             error_msg = 'Strategy "detector_closest_by_time" not available ' \
