@@ -3,7 +3,7 @@
 from http import HTTPStatus
 
 from ..common.base import Base
-from ..common.config import CALIBRATION, CREATE, DELETE, UPDATE, GET
+from ..common.config import *
 
 MODULE_NAME = CALIBRATION
 
@@ -63,8 +63,8 @@ class Calibration:
         return Base.format_response(response, GET, HTTPStatus.OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_by_name(cal_client, name):
-        response = cal_client.get_all_calibrations_by_name_api(name)
+    def get_all_by_name(cal_client, name, page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+        response = cal_client.get_all_calibrations_by_name_api(name, page, page_size)
 
         Base.cal_debug(MODULE_NAME, 'get_all_by_name', response)
         return Base.format_response(response, GET, HTTPStatus.OK, MODULE_NAME)
