@@ -3,7 +3,7 @@
 from http import HTTPStatus
 
 from ..common.base import Base
-from ..common.config import CALIBRATION_CONSTANT_VERSION, CREATE, UPDATE, GET
+from ..common.config import *
 
 MODULE_NAME = CALIBRATION_CONSTANT_VERSION
 
@@ -102,9 +102,9 @@ class CalibrationConstantVersion:
         return Base.format_response(resp, GET, HTTPStatus.OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_by_name(cal_client, name):
+    def get_all_by_name(cal_client, name, page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
         resp = cal_client.get_all_calibration_constant_versions_by_name_api(
-            name
+            name, page, page_size
         )
 
         Base.cal_debug(MODULE_NAME, 'get_all_by_name', resp)
@@ -141,6 +141,23 @@ class CalibrationConstantVersion:
         Base.cal_debug(MODULE_NAME, 'ccv >> get_by_uk', resp)
         return Base.format_response(resp, GET, HTTPStatus.OK, MODULE_NAME)
 
+    # Returns the CCV (of several CCs) for which the provided event_at is between
+    # the CCV.begin_at and CCV.end_at
+    @staticmethod
+    def get_prior_in_time(cal_client,
+                          calibration_constant_ids,
+                          physical_detector_unit_id,
+                          event_at, snapshot_at):
+        resp = cal_client.get_prior_in_time_calibration_constant_version_api(
+            calibration_constant_ids, physical_detector_unit_id,
+            event_at, snapshot_at
+        )
+
+        Base.cal_debug(MODULE_NAME,
+                       'ccv >> get_prior_in_time',
+                       resp)
+        return Base.format_response(resp, GET, HTTPStatus.OK, MODULE_NAME)
+
     # Returns the CCV (of several CCs) with closest relation between the
     # provided event_at and the CCV.begin_at
     @staticmethod
