@@ -3,7 +3,7 @@
 from http import HTTPStatus
 
 from ..common.base import Base
-from ..common.config import PHYSICAL_DETECTOR_UNIT, CREATE, DELETE, UPDATE, GET
+from ..common.config import *
 
 MODULE_NAME = PHYSICAL_DETECTOR_UNIT
 
@@ -11,13 +11,14 @@ MODULE_NAME = PHYSICAL_DETECTOR_UNIT
 class PhysicalDetectorUnit:
     def __init__(self, calibration_client,
                  physical_name, karabo_da, virtual_device_name,
-                 detector_type_id, detector_id,
+                 uuid, detector_type_id, detector_id,
                  flg_available, description=''):
         self.calibration_client = calibration_client
         self.id = None
         self.physical_name = physical_name
         self.karabo_da = karabo_da
         self.virtual_device_name = virtual_device_name
+        self.uuid = uuid
         self.detector_type_id = detector_type_id
         self.detector_id = detector_id
         self.flg_available = flg_available
@@ -66,26 +67,33 @@ class PhysicalDetectorUnit:
         return Base.format_response(response, GET, HTTPStatus.OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_by_name(cal_client, physical_name):
+    def get_all_by_name(cal_client, physical_name,
+                        page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+
         resp = cal_client.get_all_physical_detector_units_by_physical_name_api(
-            physical_name)
+            physical_name, page, page_size)
 
         Base.cal_debug(MODULE_NAME, 'get_all_by_name', resp)
         return Base.format_response(resp, GET, HTTPStatus.OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_by_detector_id(cal_client, det_id):
+    def get_all_by_detector_id(cal_client, det_id,
+                               page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
         resp = cal_client.get_all_physical_detector_units_by_detector_id_api(
-            det_id)
+            det_id, page, page_size)
 
         Base.cal_debug(MODULE_NAME, 'get_all_by_detector_id', resp)
         return Base.format_response(resp, GET, HTTPStatus.OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_by_detector_and_karabo_da(cal_client, det_id, krb_da):
+    def get_all_by_detector_and_karabo_da(cal_client, det_id, krb_da,
+                                          page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+
         resp = cal_client.get_all_physical_detector_units_by_det_and_krbda_api(
             det_id,
-            krb_da)
+            krb_da,
+            page,
+            page_size)
 
         Base.cal_debug(MODULE_NAME, 'get_all_by_detector_and_karabo_da', resp)
         return Base.format_response(resp, GET, HTTPStatus.OK, MODULE_NAME)
@@ -120,6 +128,7 @@ class PhysicalDetectorUnit:
                 'physical_name': self.physical_name,
                 'karabo_da': self.karabo_da,
                 'virtual_device_name': self.virtual_device_name,
+                'uuid': self.uuid,
                 'detector_type_id': self.detector_type_id,
                 'detector_id': self.detector_id,
                 'flg_available': self.flg_available,
