@@ -6,6 +6,7 @@ from http import HTTPStatus
 import pytest
 
 from .api_base import ApiBase
+from ..common.config_test import *
 
 
 @pytest.mark.usefixtures('client_cls')
@@ -143,8 +144,9 @@ class DetectorApiTest(ApiBase, unittest.TestCase):
         assert receive == expect
         assert response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY
 
-    def __get_all_entries_by_name_api(self, name, expect):
-        response = self.cal_client.get_all_detectors_by_name_api(name)
+    def __get_all_entries_by_name_api(self, name, expect,
+                                      page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+        response = self.cal_client.get_all_detectors_by_name_api(name, page, page_size)
         receive = self.get_and_validate_all_entries_by_name(response)
         self.fields_validation(receive, expect)
 
