@@ -6,7 +6,7 @@ from http import HTTPStatus
 import pytest
 
 from .api_base import ApiBase
-from ..common.config_test import PHYSICAL_DETECTOR_UNIT
+from ..common.config_test import *
 from ..common.generators import generate_unique_name
 
 
@@ -128,8 +128,10 @@ class PhysicalDetectorUnitApiTest(ApiBase, unittest.TestCase):
         assert expect['flg_available'] != expect_upd['flg_available']
         assert expect['description'] != expect_upd['description']
 
-    def __get_all_entries_by_name_api(self, physical_name, expect):
-        resp = self.cal_client.get_all_physical_detector_units_by_physical_name_api(physical_name)  # noqa
+    def __get_all_entries_by_name_api(self, physical_name, expect,
+                                      page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+        resp = self.cal_client.get_all_physical_detector_units_by_physical_name_api(physical_name,
+                                                                                    page, page_size)  # noqa
         receive = self.get_and_validate_all_entries_by_name(resp)
         self.fields_validation(receive, expect)
 
