@@ -20,6 +20,7 @@ class PhysicalDetectorUnitTest(ModuleBase, unittest.TestCase):
             'physical_name': __unique_name1,
             'karabo_da': __unique_name1,
             'virtual_device_name': __unique_name1,
+            'uuid': 1001,
             'detector_type_id': -1,
             'detector_id': -1,
             'flg_available': True,
@@ -43,6 +44,7 @@ class PhysicalDetectorUnitTest(ModuleBase, unittest.TestCase):
             physical_name=self.pd_01['physical_name'],
             karabo_da=self.pd_01['karabo_da'],
             virtual_device_name=self.pd_01['virtual_device_name'],
+            uuid=self.pd_01['uuid'],
             detector_type_id=self.pd_01['detector_type_id'],
             detector_id=self.pd_01['detector_id'],
             flg_available=self.pd_01['flg_available'],
