@@ -50,11 +50,17 @@ class ReportTest(ModuleBase, unittest.TestCase):
             report_name = result1['data']['name']
             report_file_path = result1['data']['file_path']
 
-            # Create duplicated entry
-            # (should NOT throw an error and return the report from the DB)
+            # Create duplicated entry (should throw an error)
             report_01_dup = report_01
             result2 = report_01_dup.create()
-            self.assert_create_success(MODULE_NAME, result2, self.report_01)
+            expect_app_info = {'name': ['has already been taken'],
+                               'file_path': ['has already been taken']}
+            self.assert_create_error(MODULE_NAME, result2, expect_app_info)
+
+            # Set duplicated entry
+            # (should NOT throw an error and return the report from the DB)
+            result3 = report_01_dup.set()
+            self.assert_set_success(MODULE_NAME, result3, self.report_01)
 
             # Get entry by name & file_path
             result3 = Report.get_by_name_and_file_path(self.cal_client,
